# Generated by Pod::WikiDoc version 0.18

=pod

=head1 NAME

sys::process - Information about the currently running Perl interpreter.

=head1 VERSION

This document describes sys::process version v0.1

=head1 SYNOPSIS

     use sys::process;
 
 
     my $euid = sys::process->euid;
 
     sys::process->euid($new_value);
 
     my $uid = sys::process->uid;
 
     sys::process->uid($new_value);
 
     my $name = sys::process->name;
 
     sys::process->name($new_value);
 
     my $egid = sys::process->egid;
 
     sys::process->egid($new_value);
 
     my $pid = sys::process->pid;
 
     sys::process->pid($new_value);
 
     my $gid = sys::process->gid;
 
     sys::process->gid($new_value);

=head1 DESCRIPTION

This is the object oriented version of L<English>.

This module provides access to some objects used or maintained by
the interpreter and to functions that interact strongly with the interpreter.

=head1 SUBROUTINESE<sol>METHODS

=head2 CLASSE<sol>INSTANCE METHODS

=head3 C<<< euid($optional_new_value) >>>

Returns euid as a SCALAR.

=head3 C<<< uid($optional_new_value) >>>

Returns uid as a SCALAR.

=head3 C<<< name($optional_new_value) >>>

Returns name as a SCALAR.

=head3 C<<< egid($optional_new_value) >>>

Returns egid as a SCALAR.

=head3 C<<< pid($optional_new_value) >>>

Returns pid as a SCALAR.

=head3 C<<< gid($optional_new_value) >>>

Returns gid as a SCALAR.

=head1 DEPENDENCIES

=over

=item *

L<version>

=back

=over

=item *

L<Class::Dot>

=back

=over

=item *

L<Scalar::Util>

=back

=head1 INCOMPATIBILITIES

None known.

=head1 BUGS AND LIMITATIONS

No bugs have been reported.

Please report any bugs or feature requests to
L<bug-class-dot@rt.cpan.org|mailto:bug-class-dot@rt.cpan.org>, or through the
web interface at L<CPAN Bug tracker|http://rt.cpan.org>.

=head1 SEE ALSO

=over

=item *

L<perlvar>

=back

=over

=item *

L<English>

=back

=head1 AUTHOR

Ask Solem, L<asksh@cpan.org>.

=head1 LICENSE AND COPYRIGHT

Copyright (c), 2007 Ask Solem L<ask@0x61736b.net|mailto:ask@0x61736b.net>.

C<<< sys >>> is distributed under the Modified BSD License.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this
list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice,
this
list of conditions and the following disclaimer in the documentation andE<sol>or
other materials provided with the distribution.

3. The name of the author may not be used to endorse or promote products
derived
from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED                        
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF                                
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO                          
EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,                              
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,                        
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR                      
BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER                       
IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)                          
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE                          
POSSIBILITY OF SUCH DAMAGE.

=head1 DISCLAIMER OF WARRANTY

BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY FOR THE
SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN OTHERWISE
STATED IN WRITING THE COPYRIGHT HOLDERS ANDE<sol>OR OTHER PARTIES PROVIDE THE
SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED,
INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND
PERFORMANCE OF THE SOFTWARE IS WITH YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE,
YOU ASSUME THE COST OF ALL NECESSARY SERVICING, REPAIR, OR CORRECTION.

IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING WILL ANY
COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY ANDE<sol>OR REDISTRIBUTE THE
SOFTWARE AS PERMITTED BY THE ABOVE LICENSE, BE LIABLE TO YOU FOR DAMAGES,
INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING
OUT OF THE USE OR INABILITY TO USE THE SOFTWARE (INCLUDING BUT NOT LIMITED TO
LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR
THIRD PARTIES OR A FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER
SOFTWARE), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE
POSSIBILITY OF SUCH DAMAGES.


=for stopwords expandtab shiftround
